@@ -1,11 +1,20 @@
 <?php
 
-$server = "{cyrus.andrew.cmu.edu:143}";
-$bboards = array("archive.info-cyrus", "archive.cyrus-sasl", "archive.c-client", "archive.imap");
+$base_url = sprintf("http://%s/archive", $HTTP_SERVER_VARS['HTTP_HOST']);
+$authenticated = (bool)get_cfg_var('imap_use_gss');
 
-function printheader($box, $msgnum, $subtitle) {
+if($authenticated) {
+  putenv("KRB5CCNAME=".$_SERVER["KRB5CCNAME"]);
+  $server = "{cyrus.andrew.cmu.edu:143/user=" . $_SERVER["REMOTE_USER"] . "}";
+} else {
+  $server = "{cyrus.andrew.cmu.edu:143/anonymous}";
+}
+
+$bboards = array("archive.info-cyrus", "archive.cyrus-sasl", "archive.cyrus-devel", "archive.imap", "archive.c-client", "org.acs.asg.project.mail.commits", "org.acs.asg.project.sasl.commits");
+
+function printheader($mbox, $box, $msgnum, $subtitle) {
 if($msgnum >= 0) {
-   $msgnumstr = " - $msgnum";
+   $msgnumstr = " - ".imap_msgno($mbox,$msgnum);
 } else {
    $msgnumstr = "";
 }
